| Title: | Data Set for the 'benchmarkme' Package |
|---|---|
| Description: | Crowd sourced benchmarks from running the 'benchmarkme' package. |
| Authors: | Colin Gillespie [aut, cre] (ORCID: <https://orcid.org/0000-0003-1787-0275>) |
| Maintainer: | Colin Gillespie <[email protected]> |
| License: | GPL-2 | GPL-3 |
| Version: | 1.0.4 |
| Built: | 2026-06-03 11:21:21 UTC |
| Source: | https://github.com/csgillespie/benchmarkme-data |
This package contains the results from users running the
benchmarkme package. The key function is plot_past().
https://github.com/csgillespie/benchmarkme-data
plot_past("prog")plot_past("prog")
A summary of past results
get_datatable_past(test_group, blas_optimize = NULL, cores = 0)get_datatable_past(test_group, blas_optimize = NULL, cores = 0)
test_group |
One of "prog", "matrix_fun", "matrix_cal", "read5", "read50", "read200",
"write5", "write50" or "write200". Default value |
blas_optimize |
Default |
cores |
Default |
## Need the DT package ## View all results for prog test get_datatable_past("prog")## Need the DT package ## View all results for prog test get_datatable_past("prog")
Try to determine parallel BLAS, which implies non-standard R! Compare user with elapsed time. If user >> elapsed, then parallel BLAS
is_blas_optimize(results)is_blas_optimize(results)
results |
The output from a |
Functions used for moving and creating the past_results_v2 data set from
uploaded data. The move_files function is used to moved files from the server
to another location, whilst removing any empty data sets.
make_data_set(from) move_files(from, to)make_data_set(from) move_files(from, to)
from |
A directory containing the uploaded results. |
to |
Destination directory |
One of the unit tests uploads an empty results file.
Files where the results are NULL are moved to a sub-directory (called)
empty in the to directory. If the empty directory doesn't
exist, it is created.
Currently these functions are specific to my set-up.
Plot the previous benchmarks. This function creates two figures.
Figure 1: Total benchmark time over all benchmarks (in seconds) on the y-axis.
Figure 2: Relative time (compared to the smallest benchmark).
The data set used is data(past_results_v2).
plot_past(test_group, blas_optimize = NULL, cores = 0, log = "y")plot_past(test_group, blas_optimize = NULL, cores = 0, log = "y")
test_group |
One of "prog", "matrix_fun", "matrix_cal", "read5", "read50", "read200",
"write5", "write50" or "write200". Default value |
blas_optimize |
Default |
cores |
Default |
log |
By default the y axis is plotted on the log scale. To change, set the
the argument equal to the empty parameter string, |
## Plot all past results for the `prog` benchmark plot_past("prog", blas_optimize = NULL)## Plot all past results for the `prog` benchmark plot_past("prog", blas_optimize = NULL)
Selects and aggregates over the past_results_v2 data set or the
results input data set..
summarise_results(res) select_results(test_group, results = NULL, blas_optimize = NULL, cores = 0)summarise_results(res) select_results(test_group, results = NULL, blas_optimize = NULL, cores = 0)
res |
A list containing benchmark results and system information. |
test_group |
One of "prog", "matrix_fun", "matrix_cal", "read5", "read50", "read200",
"write5", "write50" or "write200". Default value |
results |
Default |
blas_optimize |
Default |
cores |
Default |
A data frame
select_results("prog", blas_optimize = NULL)select_results("prog", blas_optimize = NULL)